import Qt 4.7

Item {
    id: statusDialogItem
    signal clicked(string text, string reply, string dm)
    width: parent.width; height: 150
    state: "hidden"
    property string statusText: ""
    property string replyName: ""
    property string replyID: ""
    property string dmUserID: ""

    Timer {
        id: lengthChecker
        interval: 1000
        repeat: true
        onTriggered: {
            var remaining = 140 - tweetText.text.length;
            tweetLength.text = remaining;
        }
    }

    CustomTheme {
        id: theme
    }

    Rectangle {
        id: statusDialog
        width: parent.width
        y: 0
        height: statusButtonContainer.y + statusButtonContainer.height + 20
	
        color: theme.dialogBG

        Text {
            id: statusLabel
            text: replyID!="" ? "Reply to " + statusDialogItem.replyName : (dmUserID!="" ? "Direct message" : "Status update")
            font.pixelSize: 22
            color: "#eee"
            y: 20
            x: 10
        }

        Text {
            id: tweetLength
            text: ""
            font.pixelSize: 22
            color: "#ddd"
            y: 20
            x: 10
            width: parent.width-20
            horizontalAlignment: Text.AlignRight
        }


        Rectangle {
            id: tweetTextContainer
            height: 110
            width: parent.width-20
            x: 10
            y: statusLabel.y + statusLabel.height
            gradient: Gradient {
                GradientStop { position: 0.0; color: "#ccc" }
                GradientStop { position: 0.1; color: "#fafafa" }
                GradientStop { position: 1.0; color: "#fff" }
            }
            radius: 5
            border.width: 1
            border.color: "#aaa"
            smooth: true

            TextEdit {
                id: tweetText
                wrapMode: TextEdit.Wrap
                text: statusDialogItem.statusText
                textFormat: TextEdit.PlainText
                width: parent.width - 10
                height: parent.height - 10
                x: 5
                y: 5
                color: "#111"
                font.pixelSize: 22
            }
        }

        Rectangle {
            id: statusButtonContainer
            radius: 5
            color: theme.dialogButtonAreaBG // "#999"
            x: 10
            width: parent.width - 20
            height: 70
            y: tweetTextContainer.y + tweetTextContainer.height + 20

            Row {
                id: buttonRow
                x: 10
                width: parent.width - 10
                height: 50
                spacing: 10
                y: 10

                Button {
                    id: tweetButton
                    label: "Tweet"
                    width: (parent.width / 3) * 2 - 10
                    height: 50
                    onClicked: {
                        statusDialogItem.clicked(tweetText.text, statusDialogItem.replyID, statusDialogItem.dmUserID);
                        statusDialogItem.state = "hidden";
                    }
                }

                Button {
                    id: cancelButton
                    label: "Cancel"
                    width: parent.width / 3 - 10
                    height: 50
                    onClicked: {
                        statusDialogItem.statusText = "";
                        statusDialogItem.state = "hidden"
                        statusDialogItem.replyID = "";
                        statusDialogItem.dmUserID = "";
                    }
                }
            }
        }

	
        Image {
            source: "../pics/top-shadow.png"
            y: parent.height
            height: 16
            anchors.right: parent.right
            anchors.rightMargin: 0
            anchors.left: parent.left
            anchors.leftMargin: 0
        }
    }

    states: [
        State {
            name: "hidden"
            PropertyChanges {
                target: statusDialog
                y: 0 - statusDialog.height - 16
            }
        },
        State {
            name: "shown"
            changes: [
                PropertyChanges {
                    target: statusDialog
                    y: 0
                },
                PropertyChanges {
                    target: statusDialog
                    visible: true
                }
            ]
        }
    ]

    transitions: [
        Transition {
            to: "hidden"
            SequentialAnimation {
                PropertyAnimation {
                    target: statusDialog
                    properties: "y"
                    duration: 600
                    easing.type: "OutQuad"
                }
                ScriptAction {
                    script: {
                        console.log("Stopping timer");
                        lengthChecker.stop();
                        statusDialog.visible = false;
                    }
                }
            }
        },
        Transition {
            to: "shown"
            SequentialAnimation {
                PropertyAnimation {
                    target: statusDialog
                    properties: "y"
                    duration: 600
                    easing.type: "OutQuad"
                }
                ScriptAction {
                    script: {
                        console.log("Starting timer");
                        lengthChecker.start();
                    }
                }
            }
        }
    ]

}
